@@ -19,31 +19,33 @@ def main():
 
     p = CSSParser()
     sheet = p.parseString(css)
-    
-    print("""cssText in different encodings, depending on the console some
-     chars may look broken but are actually not""")
-    print() 
-    
+
+    print(
+        """cssText in different encodings, depending on the console some
+     chars may look broken but are actually not"""
+    )
+    print()
+
     sheet.encoding = 'ascii'
     print(sheet.cssText)
     print()
-    
+
     sheet.encoding = 'iso-8859-1'
     print(sheet.cssText)
     print()
-    
+
     sheet.encoding = 'iso-8859-15'
     print(sheet.cssText)
     print()
-    
+
     sheet.encoding = 'utf-8'
     print(sheet.cssText)
     print()
-    
+
     # results in default UTF-8 encoding without @charset rule
     sheet.encoding = None
     print(sheet.cssText)
 
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
