@@ -26,9 +26,10 @@ def main():
     print("\n--- CSSParser(raiseExceptions=True) ---")
     p = cssutils.CSSParser(raiseExceptions=True)
     try:
-        c2 = p.parseString(css)
+        p.parseString(css)
     except xml.dom.DOMException as e:
         print(":::RAISED:::", e)
 
+
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
